@@ -31,78 +31,81 @@
 # STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 # THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-from adi.ad936x import ad9361, ad9363, ad9364, Pluto
-
-from adi.fmcomms5 import FMComms5
-
-from adi.ad9371 import ad9371
-
-from adi.adrv9002 import adrv9002
-
-from adi.adrv9009 import adrv9009
-
-from adi.adrv9009_zu11eg import adrv9009_zu11eg
-
-from adi.adrv9009_zu11eg_multi import adrv9009_zu11eg_multi
-
-from adi.adrv9009_zu11eg_fmcomms8 import adrv9009_zu11eg_fmcomms8
-
-from adi.ad9081 import ad9081
-
-from adi.ad9081_mc import ad9081_mc, QuadMxFE
-
-from adi.ad9094 import ad9094
-
-from adi.ad9680 import ad9680
-
-from adi.ad9136 import ad9136
-
-from adi.ad9144 import ad9144
-
-from adi.ad9152 import ad9152
-
-from adi.cn0532 import cn0532
-
-from adi.daq2 import DAQ2
-
-from adi.daq3 import DAQ3
-
-from adi.adis16460 import adis16460
-
-from adi.adis16507 import adis16507
-
-from adi.ad7124 import ad7124
-
-from adi.adxl345 import adxl345
-
-from adi.adxrs290 import adxrs290
-
-from adi.fmclidar1 import fmclidar1
-
+from adi.ad717x import ad717x
+from adi.ad719x import ad719x
+from adi.ad916x import ad9166
+from adi.ad936x import Pluto, ad9361, ad9363, ad9364
+from adi.ad4110 import ad4110
+from adi.ad4130 import ad4130
+from adi.ad4630 import ad4630
 from adi.ad5686 import ad5686
-
-from adi.adar1000 import adar1000, adar1000_array
-
-from adi.ltc2983 import ltc2983
-
-from adi.one_bit_adc_dac import one_bit_adc_dac
-
-from adi.ltc2314_14 import ltc2314_14
-
+from adi.ad5940 import ad5940
+from adi.ad7124 import ad7124
 from adi.ad7606 import ad7606
-
-from adi.ad7799 import ad7799
-
-from adi.ad7746 import ad7746
-
-from adi.adpd410x import adpd410x
-
 from adi.ad7689 import ad7689
+from adi.ad7746 import ad7746
+from adi.ad7799 import ad7799
+from adi.ad9081 import ad9081
+from adi.ad9081_mc import QuadMxFE, ad9081_mc
+from adi.ad9083 import ad9083
+from adi.ad9094 import ad9094
+from adi.ad9136 import ad9136
+from adi.ad9144 import ad9144
+from adi.ad9152 import ad9152
+from adi.ad9172 import ad9172
+from adi.ad9250 import ad9250
+from adi.ad9265 import ad9265
+from adi.ad9371 import ad9371
+from adi.ad9434 import ad9434
+from adi.ad9467 import ad9467
+from adi.ad9625 import ad9625
+from adi.ad9680 import ad9680
+from adi.ada4961 import ada4961
+from adi.adar1000 import adar1000, adar1000_array
+from adi.adf4159 import adf4159
+from adi.adf4371 import adf4371
+from adi.adf5610 import adf5610
+from adi.adg2128 import adg2128
+from adi.adis16460 import adis16460
+from adi.adis16495 import adis16495
+from adi.adis16507 import adis16507
+from adi.adl5960 import adl5960
+from adi.admv8818 import admv8818
+from adi.adpd188 import adpd188
+from adi.adpd410x import adpd410x
+from adi.adpd1080 import adpd1080
+from adi.adrf5720 import adrf5720
+from adi.adrv9002 import adrv9002
+from adi.adrv9009 import adrv9009
+from adi.adrv9009_zu11eg import adrv9009_zu11eg
+from adi.adrv9009_zu11eg_fmcomms8 import adrv9009_zu11eg_fmcomms8
+from adi.adrv9009_zu11eg_multi import adrv9009_zu11eg_multi
+from adi.adxl313 import adxl313
+from adi.adxl345 import adxl345
+from adi.adxl355 import adxl355
+from adi.adxrs290 import adxrs290
+from adi.cn0511 import cn0511
+from adi.cn0532 import cn0532
+from adi.daq2 import DAQ2
+from adi.daq3 import DAQ3
+from adi.fmc_vna import fmcvna
+from adi.fmcadc3 import fmcadc3
+from adi.fmcjesdadc1 import fmcjesdadc1
+from adi.fmclidar1 import fmclidar1
+from adi.fmcomms5 import FMComms5
+from adi.gen_mux import genmux
+from adi.lm75 import lm75
+from adi.ltc2314_14 import ltc2314_14
+from adi.ltc2983 import ltc2983
+from adi.max31855 import max31855
+from adi.one_bit_adc_dac import one_bit_adc_dac
+from adi.QuadMxFE_multi import QuadMxFE_multi
+from adi.tdd import tdd
 
 try:
     from adi.jesd import jesd
 except ImportError:
     pass
 
-__version__ = "0.0.8"
+__version__ = "0.0.13"
 name = "Analog Devices Hardware Interfaces"
