@@ -32,16 +32,16 @@
 # THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 import datetime
-import threading
 import time
 from typing import List
 
 from adi.adrv9009_zu11eg import adrv9009_zu11eg
 from adi.adrv9009_zu11eg_fmcomms8 import adrv9009_zu11eg_fmcomms8
+from adi.jesd import jesd as jesd_api
 
 
 class adrv9009_zu11eg_multi(object):
-    """ ADRV9009-ZU11EG Multi-SOM Manager
+    """ADRV9009-ZU11EG Multi-SOM Manager
 
     parameters:
         primary_uri: type=string
@@ -69,6 +69,13 @@ class adrv9009_zu11eg_multi(object):
         fmcomms8=False,
     ):
 
+        if not jesd_api:
+            raise Exception(
+                "JESD optional dependencies are required.\n"
+                + "Please install them using pip install pyadi-iio[jesd] "
+                + "or pip install paramiko"
+            )
+
         if not isinstance(secondary_uris, list):
             Exception("secondary_uris must be a list")
         if not isinstance(secondary_jesds, list):
@@ -109,7 +116,7 @@ class adrv9009_zu11eg_multi(object):
             dev._rxadc.set_kernel_buffers_count(1)
 
     def reinitialize(self):
-        """ reinitialize: reinitialize all transceivers """
+        """reinitialize: reinitialize all transceivers"""
         for dev in self.secondaries + [self.primary]:
             property_names = [p for p in dir(dev) if "reinitialize" in p]
             for p in property_names:
@@ -209,7 +216,7 @@ class adrv9009_zu11eg_multi(object):
         if (state_last == 1) and (paused == 0):
             return "done"
 
-        return "undef"
+        assert False
 
     def __jesd204_fsm_is_done(self):
         cnt = 0
@@ -228,6 +235,12 @@ class adrv9009_zu11eg_multi(object):
 
             for index, dev in enumerate(self.secondaries + [self.primary]):
                 ret = self._device_is_running(dev, index, self._jesd_fsm_show_status)
+                if index == 0:
+                    statep = dev.jesd204_fsm_state
+                else:
+                    state = dev.jesd204_fsm_state
+                    assert state == statep
+
                 if ret == "paused":
                     dev.jesd204_fsm_resume = "1"
 
@@ -265,12 +278,12 @@ class adrv9009_zu11eg_multi(object):
         return vals
 
     def hmc7044_set_cap_sel(self, vals):
-        """ hmc7044_set_cap_sel:
+        """hmc7044_set_cap_sel:
 
-            parameters:
-                vals: type=list
-                    Forces certain Capacitor bank seletions.
-                    Typically the list returned form hmc7044_cap_sel
+        parameters:
+            vals: type=list
+                Forces certain Capacitor bank seletions.
+                Typically the list returned form hmc7044_cap_sel
         """
         for dev in [self.primary] + self.secondaries:
             dev._clock_chip.reg_write(0xB2, vals.pop(0) << 2 | 1)
@@ -281,15 +294,15 @@ class adrv9009_zu11eg_multi(object):
         self.primary._clock_chip_ext.reg_write(0xB2, vals.pop(0) << 2 | 1)
 
     def hmc7044_ext_output_delay(self, chan, digital, analog_ps):
-        """ hmc7044_ext_output_delay:
+        """hmc7044_ext_output_delay:
 
-            parameters:
-                digital: type=int
-                    Digital delay. Adjusts the phase of the divider signal
-                    by up to 17 half cycles of the VCO.
-                analog_ps: type=int
-                    Analog delay. Adjusts the delay of the divider signal in
-                    increments of ~25 ps. Range is from 100ps to 700ps.
+        parameters:
+            digital: type=int
+                Digital delay. Adjusts the phase of the divider signal
+                by up to 17 half cycles of the VCO.
+            analog_ps: type=int
+                Analog delay. Adjusts the delay of the divider signal in
+                increments of ~25 ps. Range is from 100ps to 700ps.
         """
         assert 0 <= chan <= 13
         if analog_ps - 100 >= 0:
@@ -305,15 +318,15 @@ class adrv9009_zu11eg_multi(object):
         self.primary._clock_chip_ext.reg_write(0xCC + offs, int(digital) & 0x1F)
 
     def hmc7044_car_output_delay(self, chan, digital, analog_ps):
-        """ hmc7044_car_output_delay:
+        """hmc7044_car_output_delay:
 
-            parameters:
-                digital: type=int
-                    Digital delay. Adjusts the phase of the divider signal
-                    by up to 17 half cycles of the VCO.
-                analog_ps: type=int
-                    Analog delay. Adjusts the delay of the divider signal in
-                    increments of ~25 ps. Range is from 100ps to 700ps.
+        parameters:
+            digital: type=int
+                Digital delay. Adjusts the phase of the divider signal
+                by up to 17 half cycles of the VCO.
+            analog_ps: type=int
+                Analog delay. Adjusts the delay of the divider signal in
+                increments of ~25 ps. Range is from 100ps to 700ps.
         """
         assert 0 <= chan <= 13
         if analog_ps - 100 >= 0:
@@ -334,11 +347,7 @@ class adrv9009_zu11eg_multi(object):
         for dev in self.secondaries + [self.primary]:
             if self._dma_show_arming:
                 print("--DMA ARMING--", dev.uri)
-            dev._rxadc.reg_write(0x80000044, 0x8)
-            while dev._rxadc.reg_read(0x80000068) == 0:
-                dev._rxadc.reg_write(0x80000044, 0x8)
-                if self._dma_show_arming:
-                    print(".", end="")
+            dev.rx_sync_start = "arm"
             if self._dma_show_arming:
                 print("\n--DMA ARMED--", dev.uri)
 
@@ -346,22 +355,21 @@ class adrv9009_zu11eg_multi(object):
         for dev in self.secondaries + [self.primary]:
             if self._dma_show_arming:
                 print("--DAC SYNC ARMING--", dev.uri)
-            chan = dev._txdac.find_channel("altvoltage0", True)
-            chan.attrs["raw"].value = str(enable)
+            dev.tx_sync_start = "arm"
 
     def sysref_request(self):
-        """ sysref_request: Sysref request for parent HMC7044 """
+        """sysref_request: Sysref request for parent HMC7044"""
         if self._request_sysref_carrier:
             self.primary._clock_chip_carrier.attrs["sysref_request"].value = "1"
         else:
             self.primary._clock_chip_ext.attrs["sysref_request"].value = "1"
 
     def set_trx_lo_frequency(self, freq):
-        """ set_trx_lo_frequency:
+        """set_trx_lo_frequency:
 
-            parameters:
-                freq: type=int
-                    Frequency in hertz to be applied to all LOs
+        parameters:
+            freq: type=int
+                Frequency in hertz to be applied to all LOs
         """
         for dev in self.secondaries + [self.primary]:
             dev._set_iio_debug_attr_str("adi,trx-pll-lo-frequency_hz", freq, dev._ctrl)
@@ -376,6 +384,20 @@ class adrv9009_zu11eg_multi(object):
                     "adi,trx-pll-lo-frequency_hz", freq, dev._ctrl_d
                 )
 
+    def set_trx_framer_a_loopback(self, enable):
+        """set_trx_framer_a_loopback: Set bist_framer_a_loopback
+        """
+        for dev in self.secondaries + [self.primary]:
+            dev._set_iio_debug_attr_str("bist_framer_a_loopback", enable, dev._ctrl)
+            dev._set_iio_debug_attr_str("bist_framer_a_loopback", enable, dev._ctrl_b)
+            if self.fmcomms8:
+                dev._set_iio_debug_attr_str(
+                    "bist_framer_a_loopback", enable, dev._ctrl_c
+                )
+                dev._set_iio_debug_attr_str(
+                    "bist_framer_a_loopback", enable, dev._ctrl_d
+                )
+
     def __refill_samples(self, dev, is_primary):
         if is_primary:
             self.samples_primary = dev.rx()
@@ -416,13 +438,13 @@ class adrv9009_zu11eg_multi(object):
         raise Exception("Unable to initialize (Board reboot required)")
 
     def rx(self):
-        """ Receive data from multiple hardware buffers for each channel index in
-            rx_enabled_channels of each child object (primary,secondaries[indx]).
+        """Receive data from multiple hardware buffers for each channel index in
+        rx_enabled_channels of each child object (primary,secondaries[indx]).
 
-            returns: type=numpy.array or list of numpy.array
-                An array or list of arrays when more than one receive channel
-                is enabled containing samples from a channel or set of channels.
-                Data will be complex when using a complex data device.
+        returns: type=numpy.array or list of numpy.array
+            An array or list of arrays when more than one receive channel
+            is enabled containing samples from a channel or set of channels.
+            Data will be complex when using a complex data device.
         """
         if not self._rx_initialized:
             self._pre_rx_setup()
