@@ -35,6 +35,11 @@ from adi.ad936x import ad9361
 from adi.context_manager import context_manager
 from adi.rx_tx import rx_tx
 
+try:
+    import ad9361 as libad9361
+except ImportError:
+    libad9361 = None
+
 
 class FMComms5(ad9361):
     """ FMComms5 Dual Transceiver Evaluation Board """
@@ -71,7 +76,9 @@ class FMComms5(ad9361):
         self._txdac = self._ctx.find_device("cf-ad9361-dds-core-lpc")
         self._rxadc_chip_b = self._ctx.find_device("cf-ad9361-B")
         self._txdac_chip_b = self._ctx.find_device("cf-ad9361-dds-core-B")
-        rx_tx.__init__(self)
+        rx_tx.__init__(self)  # pylint: disable=W0233
+        if libad9361:
+            libad9361.fmcomms5_multichip_sync(self._ctx, 3)
 
     @property
     def filter(self):
@@ -104,7 +111,9 @@ class FMComms5(ad9361):
     def gain_control_mode_chip_b_chan0(self):
         """gain_control_mode_chip_b_chan0: Mode of receive path AGC of second transceiver.
         Options are: slow_attack, fast_attack, manual"""
-        return self._get_iio_attr("voltage0", "gain_control_mode", False, self._ctrl_b)
+        return self._get_iio_attr_str(
+            "voltage0", "gain_control_mode", False, self._ctrl_b
+        )
 
     @gain_control_mode_chip_b_chan0.setter
     def gain_control_mode_chip_b_chan0(self, value):
@@ -114,7 +123,9 @@ class FMComms5(ad9361):
     def gain_control_mode_chip_b_chan1(self):
         """gain_control_mode_chip_b_chan1: Mode of receive path AGC of second transceiver.
         Options are: slow_attack, fast_attack, manual"""
-        return self._get_iio_attr("voltage1", "gain_control_mode", False, self._ctrl_b)
+        return self._get_iio_attr_str(
+            "voltage1", "gain_control_mode", False, self._ctrl_b
+        )
 
     @gain_control_mode_chip_b_chan1.setter
     def gain_control_mode_chip_b_chan1(self, value):
